@@ -9,6 +9,7 @@ from typing import (
     Dict,
     Generator,
     List,
+    Sequence,
     Tuple,
     Union,
     cast,
@@ -44,6 +45,7 @@ from web3.types import (
     LogReceipt,
     Nonce,
     RPCEndpoint,
+    TopicFilter,
     TxData,
     Wei,
 )
@@ -171,7 +173,7 @@ async def idle_handler(
 
 
 async def emit_contract_event(
-    async_w3: AsyncWeb3,
+    async_w3: "AsyncWeb3[Any]",
     acct: ChecksumAddress,
     contract_function: "AsyncContractFunction",
     args: Any = (),
@@ -184,7 +186,7 @@ async def emit_contract_event(
 
 
 async def log_indexed_and_non_indexed_args_task(
-    async_w3: AsyncWeb3,
+    async_w3: "AsyncWeb3[Any]",
     async_emitter_contract: "AsyncContract",
     acct: ChecksumAddress,
     delay: float = 0.1,
@@ -224,14 +226,14 @@ async def clean_up_task(task: "asyncio.Task[Any]") -> None:
 
 class PersistentConnectionProviderTest:
     @pytest.fixture(autouse=True)
-    def clear_caches(self, async_w3: AsyncWeb3) -> Generator[None, None, None]:
+    def clear_caches(self, async_w3: "AsyncWeb3[Any]") -> Generator[None, None, None]:
         yield
         async_w3.provider._request_processor.clear_caches()
         async_w3.subscription_manager.total_handler_calls = 0
 
     @staticmethod
     async def seed_transactions_to_geth(
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
         acct: ChecksumAddress,
         num_txs: int = 1,
         delay: float = 0.1,
@@ -303,7 +305,7 @@ class PersistentConnectionProviderTest:
     )
     async def test_async_eth_subscribe_syncing_mocked(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
         subscription_params: Tuple[Any, ...],
         ws_subscription_response: Dict[str, Any],
         expected_formatted_result: Any,
@@ -334,7 +336,9 @@ class PersistentConnectionProviderTest:
         )
 
     @pytest.mark.asyncio
-    async def test_async_eth_subscribe_new_heads(self, async_w3: AsyncWeb3) -> None:
+    async def test_async_eth_subscribe_new_heads(
+        self, async_w3: "AsyncWeb3[Any]"
+    ) -> None:
         sub_id = await async_w3.eth.subscribe("newHeads")
         assert is_hexstr(sub_id)
 
@@ -353,7 +357,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_creates_and_handles_new_heads_subscription_type(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         sub_manager = async_w3.subscription_manager
         new_heads_handler_test = SubscriptionHandlerTest()
@@ -380,7 +384,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_process_pending_tx_true(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         sub_id = await async_w3.eth.subscribe("newPendingTransactions", True)
         assert is_hexstr(sub_id)
@@ -423,7 +427,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_and_process_pending_tx_false(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         sub_id = await async_w3.eth.subscribe("newPendingTransactions")
         assert is_hexstr(sub_id)
@@ -460,7 +464,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_creates_and_handles_pending_tx_subscription_type(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         sub_manager = async_w3.subscription_manager
         pending_tx_handler_test = SubscriptionHandlerTest()
@@ -497,7 +501,7 @@ class PersistentConnectionProviderTest:
 
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_and_process_logs(
-        self, async_w3: AsyncWeb3, async_emitter_contract: "AsyncContract"
+        self, async_w3: "AsyncWeb3[Any]", async_emitter_contract: "AsyncContract"
     ) -> None:
         event = async_emitter_contract.events.LogIndexedAndNotIndexed
         event_topic = async_w3.keccak(text=event.abi_element_identifier).to_0x_hex()
@@ -536,7 +540,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_async_eth_subscribe_creates_and_handles_logs_subscription_type(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
         async_emitter_contract: "AsyncContract",
     ) -> None:
         sub_manager = async_w3.subscription_manager
@@ -580,10 +584,116 @@ class PersistentConnectionProviderTest:
         sub_manager.total_handler_calls = 0
         await clean_up_task(emit_event_task)
 
+    @pytest.mark.asyncio
+    @pytest.mark.parametrize(
+        "topics",
+        [
+            pytest.param(
+                [
+                    HexStr(
+                        "0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef"  # noqa: E501
+                    )
+                ],
+                id="Single specific topic at position 0",
+            ),
+            pytest.param(
+                [
+                    None,
+                    HexStr(
+                        "0xabcdef1234567890abcdef1234567890abcdef1234567890abcdef1234567890"  # noqa: E501
+                    ),
+                ],
+                id="Wildcard at position 0, specific topic at position 1",
+            ),
+            pytest.param(
+                [
+                    [
+                        HexStr(
+                            "0x1111111111111111111111111111111111111111111111111111111111111111"  # noqa: E501
+                        ),
+                        HexStr(
+                            "0x2222222222222222222222222222222222222222222222222222222222222222"  # noqa: E501
+                        ),
+                    ]
+                ],
+                id="OR pattern: topic A or B at position 0",
+            ),
+            pytest.param(
+                [
+                    [
+                        HexStr(
+                            "0xaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"  # noqa: E501
+                        ),
+                        HexStr(
+                            "0xbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb"  # noqa: E501
+                        ),
+                    ],
+                    HexStr(
+                        "0xcccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc"  # noqa: E501
+                    ),
+                ],
+                id="Complex: (A or B) at position 0 AND C at position 1",
+            ),
+            pytest.param(
+                [
+                    HexBytes(
+                        "0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef"  # noqa: E501
+                    )
+                ],
+                id="Single specific topic at position 0 with HexBytes",
+            ),
+            pytest.param(
+                [
+                    [
+                        HexBytes(
+                            "0xaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"  # noqa: E501
+                        ),
+                        HexStr(
+                            "0xbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb"  # noqa: E501
+                        ),
+                        b"\xcc" * 32,
+                    ]
+                ],
+                id="OR pattern with mixed HexBytes, HexStr, and bytes at position 0",
+            ),
+        ],
+    )
+    async def test_async_logs_subscription_with_and_or_topic_patterns(
+        self,
+        async_w3: "AsyncWeb3[Any]",
+        async_emitter_contract: "AsyncContract",
+        topics: Sequence[TopicFilter],
+    ) -> None:
+        """Test that LogsSubscription properly handles AND/OR topic patterns."""
+        sub_manager = async_w3.subscription_manager
+
+        subscription = LogsSubscription(
+            address=async_emitter_contract.address,
+            topics=topics,
+            handler=idle_handler,
+        )
+
+        await sub_manager.subscribe(subscription)
+        assert len(sub_manager.subscriptions) == 1
+        assert isinstance(sub_manager.subscriptions[0], LogsSubscription)
+        assert sub_manager.subscriptions[0].topics == topics
+
+        assert subscription.subscription_params == (
+            "logs",
+            {
+                "address": async_emitter_contract.address,
+                "topics": topics,
+            },
+        )
+
+        # clean up
+        await sub_manager.unsubscribe(subscription)
+        assert len(sub_manager.subscriptions) == 0
+
     @pytest.mark.asyncio
     async def test_async_extradata_poa_middleware_on_eth_subscription(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         async_w3.middleware_onion.inject(
             ExtraDataToPOAMiddleware, "poa_middleware", layer=0
@@ -626,7 +736,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_asyncio_gather_for_multiple_requests_matches_the_responses(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         (
             latest,
@@ -662,7 +772,7 @@ class PersistentConnectionProviderTest:
         assert chain_id == chain_id2 == chain_id3 == 131277322940537
 
     @pytest.mark.asyncio
-    async def test_async_public_socket_api(self, async_w3: AsyncWeb3) -> None:
+    async def test_async_public_socket_api(self, async_w3: "AsyncWeb3[Any]") -> None:
         # clear all caches and queues
         async_w3.provider._request_processor.clear_caches()
 
@@ -691,7 +801,7 @@ class PersistentConnectionProviderTest:
 
     @pytest.mark.asyncio
     async def test_async_subscription_manager_subscribes_to_many_subscriptions(
-        self, async_w3: AsyncWeb3, async_emitter_contract: "AsyncContract"
+        self, async_w3: "AsyncWeb3[Any]", async_emitter_contract: "AsyncContract"
     ) -> None:
         sub_manager = async_w3.subscription_manager
 
@@ -754,7 +864,9 @@ class PersistentConnectionProviderTest:
         await clean_up_task(emit_event_task)
 
     @pytest.mark.asyncio
-    async def test_subscription_handler_context(self, async_w3: AsyncWeb3) -> None:
+    async def test_subscription_handler_context(
+        self, async_w3: "AsyncWeb3[Any]"
+    ) -> None:
         base_url = "http://localhost:1337"
         async_beacon = AsyncBeacon(base_url)
         handler_test = SubscriptionHandlerTest()
@@ -802,7 +914,7 @@ class PersistentConnectionProviderTest:
 
     @pytest.mark.asyncio
     async def test_subscriptions_with_handler_and_without(
-        self, async_w3: AsyncWeb3
+        self, async_w3: "AsyncWeb3[Any]"
     ) -> None:
         handler_test = SubscriptionHandlerTest()
         stream_passed = False
@@ -851,7 +963,7 @@ class PersistentConnectionProviderTest:
     @pytest.mark.asyncio
     async def test_handle_subscriptions_breaks_on_unsubscribe(
         self,
-        async_w3: AsyncWeb3,
+        async_w3: "AsyncWeb3[Any]",
     ) -> None:
         async def unsubscribe_subs(
             subs: List[Union[NewHeadsSubscription, LogsSubscription]],
@@ -879,7 +991,7 @@ class PersistentConnectionProviderTest:
 
     @pytest.mark.asyncio
     async def test_run_forever_starts_with_0_subs_and_runs_until_task_cancelled(
-        self, async_w3: AsyncWeb3
+        self, async_w3: "AsyncWeb3[Any]"
     ) -> None:
         sub_manager = async_w3.subscription_manager
         assert_no_subscriptions_left(sub_manager._subscription_container)
